hover
    * ``auth_username`` Specify username for authentication

    * ``auth_password`` Specify password for authentication

    * ``auth_totp_secret`` Specify base32-encoded shared secret to generate an otp for authentication
